@@ -1,16 +1,18 @@
-# Copyright 2018
+# Copyright Amethyst Reese
 # Licensed under the MIT license
 
 
+from collections.abc import Coroutine, Generator
+from contextlib import AbstractAsyncContextManager
 from functools import wraps
-from typing import Any, AsyncContextManager, Callable, Coroutine, Generator, TypeVar
+from typing import Any, Callable, TypeVar
 
 from .cursor import Cursor
 
 _T = TypeVar("_T")
 
 
-class Result(AsyncContextManager[_T], Coroutine[Any, Any, _T]):
+class Result(AbstractAsyncContextManager[_T], Coroutine[Any, Any, _T]):
     __slots__ = ("_coro", "_obj")
 
     def __init__(self, coro: Coroutine[Any, Any, _T]):
@@ -45,7 +47,7 @@ class Result(AsyncContextManager[_T], Coroutine[Any, Any, _T]):
 
 
 def contextmanager(
-    method: Callable[..., Coroutine[Any, Any, _T]]
+    method: Callable[..., Coroutine[Any, Any, _T]],
 ) -> Callable[..., Result[_T]]:
     @wraps(method)
     def wrapper(self, *args, **kwargs) -> Result[_T]:
